' ************************************************************************************************
' Program:     Estimate_Historical_Potential_Output.prg                                          *
'                                                                                                *
' Purpose:     This code produces historical estimates of potential output (also referred to as  *
'              potential gross domestic product or gross value added), which are used by the     *
'              U.S. Congressional Budget Office (CBO) as input to several of CBO's economic      *
'              models. The methodology for developing the estimate is described in detail in a   *
'              CBO document, Working Paper 2018-03, "Estimating and Projecting Potential Output  *
'              Using CBO's Forecasting Growth Model" (https://www.cbo.gov/publication/53558).    *
'              Sections of that paper are referred to in comments to explain the code to guide   *
'              the user.                                                                         *
'                                                                                                *
' Input:       Input_Data_For_Estimating_Potential_Output_Quarterly.csv -- a comma-separated     *
'              text file containing 49 quarterly series.                                         *
'                                                                                                *
'              Input_Data_For_Estimating_Potential_Output_Annual.csv -- a comma-separated        *
'              text file containing 96 annual series.                                            *
'                                                                                                *
' Output:      The code estimates components of potential output for six productive sectors:     *
'               1) nonfarm business (NFB),                                                       *
'               2) farms,                                                                        *
'               3) households,                                                                   *
'               4) nonprofit institutions,                                                       *
'               5) federal government, and                                                       *
'               6) state and local governments.                                                  *
'                                                                                                *
'              Potential employment and labor hours are estimated for all sectors. Potential     *
'              output in NFB is estimated using a Cobb-Douglas production function with inputs   *
'              of potential labor hours, the estimated actual flow of services from the NFB      *
'              capital stock, and potential total factor productivity. For other sectors except  *
'              the household sector, potential output is estimated from potential labor hours    *
'              and potential labor productivity (output per hour). For the household sector,     *
'              potential output is estimated from the flow of services from the owner-occupied   *
'              housing stock. Note that this approach ignores labor income in the sector, which  *
'              is a very small portion of sectoral income. For further details see pp. 3-7 in    *
'              the working paper).                                                               *
'                                                                                                *
' Environment: Windows 10 Enterprise                                                             *
'              Eviews version 9 or 10 (http://www.eviews.com/home.html)                          *
'              NOTE: The code for the 'import' commands that bring in data from an XLSX          *
'              workbook is currently set to run in Eviews version 10. Alternative 'import'       *
'              commands that run in Eviews version 9 are provided below.                         *
'                                                                                                *
' Author:      Bob Shackleton                                                                    *
'                                                                                                *
' Release Date: July XX, 2018                                                                    *
'                                                                                                *
' ************************************************************************************************

' ************************************************************************************************
' ***                                      Parameters: Dates                                   ***
' ************************************************************************************************

 %working_directory   = ".\.."
 %date_begin_q        = "1947Q1"            ' Beginning of quarterly history
 %date_end_a_last_q   = "2016Q4"            ' Last quarter of last year of annual history
 %date_end_q          = "2017Q3"            ' End of quarterly history (2017.05.01)
 %date_begin_a        = "1947"              ' Beginning of annual history
 %date_end_a          = "2016"              ' End of annual history
 %date_fisher_begin   = "1947"              ' Beginning of Fisher index calculations
 %date_estimate_begin = "1949"              ' First year of estimate of potential output
 %base_year           = "2009"              ' Base year for iprod, icap, & ilab indices, etc.


' ************************************************************************************************
' ***               Create Workfile with Quarterly and Annual Pages, Fetch Data                ***
'                                                                                                *
' NOTE: The code for the 'import' commands is currently set to run in Eviews version 10.         *
'       To run in Eviews version 9, comment out the first set of 'import' commands and           *
'       uncomment the second set.                                                                *
'                                                                                                *
' ************************************************************************************************

wfcreate(wf = ".\CBO_Potential_Output_Estimate", page = Quarterly) q %date_begin_q %date_end_q
import .\Input_Data_For_Estimating_CBO_Potential_Output_Quarterly.csv _
       ftype=ascii rectype=crlf skip=0 fieldtype=delimited delim=comma colhead=2 _
       namepos=first eoltype=pad badfield=NA @id @date(obs) @destid @date @smpl @all

pagecreate(page = Annual) a %date_begin_a %date_end_a
import .\Input_Data_For_Estimating_CBO_Potential_Output_Annual.csv _
       ftype=ascii rectype=crlf skip=0 fieldtype=delimited delim=comma colhead=2 _
       namepos=first eoltype=pad badfield=NA @id @date(obs) @destid @date @smpl @all

' ************************************************************************************************
' ***            Fisherize the Output Aggregates and Create Output Residuals                   ***
'                                                                                                *
' In a few instances, the Fisher aggregations of components of annual real output yield small    *
' discrepancies, or residuals, compared with the aggregate values reported by the Bureau of      *
' Economic Analysis (BEA). The following procedures carry out the relevant Fisher aggregations   *
' and calculate the value of those residuals, to be used later in calculating potential values   *
' of aggregates. Fisher aggregation is carried out by calling subroutine_fisher_agg.  Creation   *
' of output residuals is not discussed in the working paper.                                     *
'                                                                                                *
' ************************************************************************************************

include subroutine_fisher_agg.prg

' First: QGDP (Real GDP)
smpl %date_begin_a %date_end_a
group component_list gdpnfb gdpaf gdpg gdpsvh
series gdpcg = gdpnfb + gdpaf + gdpg + gdpsvh
call fisher_agg(component_list, gdpcg, @pagefreq, %base_year, %date_begin_a, %date_end_a)
series qgdp_res = qgdp - qgdpcg
delete gdpcg qgdpcg pgdpcg

' Next: QGDPSVH (Real GDP in the household and nonprofit sectors)
smpl %date_begin_a %date_end_a
group component_list gdpsvhhh gdpsvhnp
series gdpsvhcg = gdpsvhhh + gdpsvhnp
call fisher_agg(component_list, gdpsvhcg, @pagefreq, %base_year, %date_begin_a, %date_end_a)
series qgdpsvh_res = qgdpsvh - qgdpsvhcg
delete gdpsvhcg qgdpsvhcg pgdpsvhcg

' Next: QGDPG (Real GDP in the government sectors)
smpl %date_begin_a %date_end_a
series pgdpgf = gdpgf / qgdpgf
series pgdpgsl = gdpgsl / qgdpgsl
group component_list gdpgf gdpgsl
series gdpgcg = gdpgf + gdpgsl
call fisher_agg(component_list, gdpgcg, @pagefreq, %base_year, %date_begin_a, %date_end_a)
series qgdpg_res = qgdpg - qgdpgcg
delete gdpgcg qgdpgcg pgdpgcg

' Next: QGDPGF (Real GDP in the federal government)
smpl %date_begin_a %date_end_a
group component_list gfwss gfocca gfmlcca
series gdpgfcg = gfwss + gfocca + gfmlcca
call fisher_agg(component_list, gdpgfcg, @pagefreq, %base_year, %date_begin_a, %date_end_a)
series qgdpgf_res = qgdpgf - qgdpgfcg
delete gdpgfcg qgdpgfcg pgdpgfcg

' Next: QGDPGSL (Real GDP in state and local governments)
smpl %date_begin_a %date_end_a
group component_list gslwss gslcca
series gdpgslcg = gslwss + gslcca
call fisher_agg(component_list, gdpgslcg, @pagefreq, %base_year, %date_begin_a, %date_end_a)
series qgdpgsl_res = qgdpgsl - qgdpgslcg
delete gdpgslcg qgdpgslcg pgdpgslcg

' Next: QGDPOTH (Real GDP in all sectors other than nonfarm business)
smpl %date_begin_a %date_end_a
group component_list gdpg gdpaf gdpsvh
series gdpoth = gdpg + gdpaf + gdpsvh
call fisher_agg(component_list, gdpoth, @pagefreq, %base_year, %date_begin_a, %date_end_a)

     gdpoth.label(d)         Gross Value Added: Other ($Billions)
     qgdpoth.label(d)        Real Gross Value Added: Other ($2009 Billions)
     pgdpoth.label(d)        Price Index, Gross Domestic Product, Other ({%base_year} = 1.0)

' ************************************************************************************************
' ***                         Estimate Potential Employment Aggregates                         ***
'                                                                                                *
' The code in this section uses estimates of the potential labor force (lcfe) and the natural    *
' rate of unemployment (rucfe) to calculate potential household employment (ehhcfe) consistent   *
' with the BLS measure of employment (that is, the number of people with jobs). It then          *
' calculates an employment gap (the difference between actual and potential household employment)*
' and a difference (e_dif) between the household measure of employment and an establishment      *
' measure of employment (that is, the number of jobs as opposed to the number of job-holders).   *
' Finally, it calculates potential values for the difference (e_diffe) and thus for total        *
' potential employment (etotalfe).                                                               *
'                                                                                                *
' The code then uses sectoral employment data to calculate sector employment shares and estimate *
' potential values for the sectoral shares, yielding estimates of potential employment by        *
' sector. The code estimates potential shares two ways, one approach using a single post2001    *
' trend and the other using a 20012007 trend as well as a post2007 trend, and takes the        *
' average of the shares estimated under the two approaches. The resulting potential shares for   *
' employment in the state and local government sector appear more realistic than the results of  *
' either approach alone, given general trends in that sector in the wake of the recession and    *
' weak recovery. The equations also include a dummy variable that takes a value of 1.0 in the    *
' second quarter of every census year, when the federal government hires a large number of       *
' people to assist in conducting the census and thus noticeably affects all the employment       *
' shares. (For further details see pp. 13-18 of the working paper.)                              *
'                                                                                                *
' ************************************************************************************************

pageselect Quarterly

' ************************************************************************************************
'               Equations (6), (7) and (8) from pp. 14-15 of the working paper.                  *
' ************************************************************************************************
smpl %date_begin_q %date_end_q
series ehhcfe = (1 - (rucfe / 100)) * lcfe
series empgap = ((ehhc / ehhcfe) - 1) * 100
series e_dif = etotal - ehhc
series re_dif = e_dif / ehhc

     ehhcfe.label(d)         Potential Household Employment (Millions)
     empgap.label(d)         Household Employment Gap (Percent)
     e_dif.label(d)          Difference, BLS and Household Survey Employment Totals (Millions)
     re_dif.label(d)         Ratio of Employment Difference to Total Household Employment     

' ************************************************************************************************
'                                   Sectoral employment shares                                   *
' ************************************************************************************************

for %variable_list enfb_emp _
                   enfb_propuf _
                   efarm _
                   esvhhh _
                   esvhnp _
                   egfc _
                   egfm_a _
                   egfm_r _
                   egsl
     series r{%variable_list} = {%variable_list}/etotal
next

     renfb_emp.label(d)      Proprietors and Unpaid Family Share of BLS Employment
     renfb_propuf.label(d)   Proprietors and Unpaid Family Share of BLS Employment
     refarm.label(d)         Farm Employment Share of BLS Employment
     resvhhh.label(d)        Household Employment Share of BLS Employment
     resvhnp.label(d)        Non-profit Employment Share of BLS Employment
     regfc.label(d)          Federal Government Civilian Share of BLS Employment
     regfm_a.label(d)        Federal Government Armed Forces Share of BLS Employment
     regfm_r.label(d)        Federal Government Military Reserve Share of BLS Employment
     regsl.label(d)          State & Local Government Share of BLS Employment

' ************************************************************************************************
'                                    Census dummy variable                                       *
'         accounts for employment shifts during quarters when Census employment peaks.           *
' ************************************************************************************************

smpl %date_begin_q %date_end_q
series dummy_census = 0.0
for %dates 1970Q2 1980Q2 1990Q2 2000Q2 2010Q2
     smpl %dates %dates
     series dummy_census = 1.0
next

     dummy_census.label(d) Regression dummy variable for Census quarters

' ************************************************************************************************
' Estimate the 'potential' difference between household and establishment measures of employment *
' and use the potential difference to calculate potential establishment employment. Also         *
' estimate potential establishment employment directly as a check to ensure that both approaches *
' yield very similar results.                                                                    *
' ************************************************************************************************

smpl %date_begin_q %date_end_q
for %dependent_variable_list re_dif _
                             etotal
     series ln_{%dependent_variable_list} = log({%dependent_variable_list})
     equation eq_{%dependent_variable_list}.ls ln_{%dependent_variable_list} _
        c empgap empgap-empgap(-1) dummy_census Trend_1948_1953 _
        Trend_1953_1957 Trend_1957_1960 Trend_1960_1969 _
        Trend_1969_1973 Trend_1973_1980 Trend_1980_1990 _
        Trend_1990_2001 Trend_2001_2007 trend_2007
     eq_{%dependent_variable_list}.fit {%dependent_variable_list}_hat
     series {%dependent_variable_list}fe = exp({%dependent_variable_list}_hat _
                 - (empgap * eq_{%dependent_variable_list}.@coefs(2)) _
                 - ((empgap-empgap(-1)) * eq_{%dependent_variable_list}.@coefs(3)) _
                 - (dummy_census * eq_{%dependent_variable_list}.@coefs(4)))
     graph gr_{%dependent_variable_list}_est.line _
                 {%dependent_variable_list} {%dependent_variable_list}fe
next

' ************************************************************************************************
' Estimate sectoral shares of establishment employment, with a 2001 Trend (equation 1) and with  *
' both a 2001-2007 Trend and a 2007 Trend (equation 2), and take the mean of the two sets of     *
' estimates. Both yield potential share equations that sum to 1.0, and weighted averages of them *
' sum to 1.0 as well. Using an average of both helps ameliorate the tendency of equation 1 to    *
' yield an estimate of a large employment gap in state and local government during the last,     *
' very slow recovery.                                                                            *
' ************************************************************************************************

smpl %date_begin_q %date_end_q
for %dependent_variable_list renfb_emp _
                             renfb_propuf _
                             refarm _
                             resvhhh _
                             resvhnp _
                             regfc _
                             regfm_a _
                             regfm_r _
                             regsl

     equation eq_{%dependent_variable_list}_1.ls {%dependent_variable_list} _
        c empgap empgap-empgap(-1) dummy_census Trend_1948_1953 _
        Trend_1953_1957 Trend_1957_1960 Trend_1960_1969 _
        Trend_1969_1973 Trend_1973_1980 Trend_1980_1990 _
        Trend_1990_2001 Trend_2001
     eq_{%dependent_variable_list}_1.fit {%dependent_variable_list}_1_hat
     series {%dependent_variable_list}1fe = {%dependent_variable_list}_1_hat _
                 - (empgap * eq_{%dependent_variable_list}_1.@coefs(2)) _
                 - ((empgap-empgap(-1)) * eq_{%dependent_variable_list}_1.@coefs(3)) _
                 - (dummy_census * eq_{%dependent_variable_list}_1.@coefs(4))
     graph gr_{%dependent_variable_list}_1_est.line _
                 {%dependent_variable_list} {%dependent_variable_list}1fe

     equation eq_{%dependent_variable_list}_2.ls {%dependent_variable_list} _
        c empgap empgap-empgap(-1) dummy_census Trend_1948_1953 _
        Trend_1953_1957 Trend_1957_1960 Trend_1960_1969 _
        Trend_1969_1973 Trend_1973_1980 Trend_1980_1990 _
        Trend_1990_2001 Trend_2001_2007 Trend_2007
     eq_{%dependent_variable_list}_2.fit {%dependent_variable_list}_2_hat
     series {%dependent_variable_list}2fe = {%dependent_variable_list}_2_hat _
                 - (empgap * eq_{%dependent_variable_list}_2.@coefs(2)) _
                 - ((empgap-empgap(-1)) * eq_{%dependent_variable_list}_2.@coefs(3)) _
                 - (dummy_census * eq_{%dependent_variable_list}_2.@coefs(4))
     graph gr_{%dependent_variable_list}_2_est.line _
                 {%dependent_variable_list} {%dependent_variable_list}2fe

     series {%dependent_variable_list}fe = ({%dependent_variable_list}1fe _
                                         +  {%dependent_variable_list}2fe) / 2
next

' ************************************************************************************************
'                                 Create figures of the results                                  *
' ************************************************************************************************

graph gr_renfb_emp renfb_emp renfb_empfe
graph gr_renfb_propuf renfb_propuf renfb_propuffe
graph gr_refarm refarm refarmfe
graph gr_resvhhh resvhhh resvhhhfe
graph gr_resvhnp resvhnp resvhnpfe
graph gr_regfc regfc regfcfe
graph gr_regfm_a regfm_a regfm_afe
graph gr_regfm_r regfm_r regfm_rfe
graph gr_regsl regsl regslfe

' ************************************************************************************************
' Adjust the estimated employment share of the military (regfm_a) and allocate the residual      *
' to nonfarm business. Adjustment brings active military share into slightly closer relation     *
' to recent history.                                                                             *
' ************************************************************************************************

smpl "2001Q1" %date_end_q
!military_employment_adjustment = 0.000015
series regfm_afe = regfm_afe(-1) - !military_employment_adjustment

' Allocate residual to nonfarm business employment
series renfb_empfe = 1.0 _
                   - renfb_propuffe _
                   - refarmfe _
                   - resvhhhfe _
                   - resvhnpfe _
                   - regfcfe _
                   - regfm_afe _
                   - regfm_rfe _
                   - regslfe

     renfb_empfe.label(d)    Potential Employment Share, NFB Employees
     renfb_propuffe.label(d) Potential Employment Share, NFB Proprietors & Unpaid Family
     refarmfe.label(d)       Potential Employment Share, Farm Sector
     resvhhhfe.label(d)      Potential Employment Share, Household Sector
     resvhnpfe.label(d)      Potential Employment Share, Nonprofit Sector
     regfcfe.label(d)        Potential Employment Share, Federal government Civilians
     regfm_afe.label(d)      Potential Employment Share, Federal government Armed Forces
     regfm_rfe.label(d)      Potential Employment Share, Federal government A.F. Reserve
     regslfe.label(d)        Potential Employment Share, State & Local

' ************************************************************************************************
' Calculate potential total establishment employment and potential sectoral employment from      *
' estimated potential sectoral shares -- equations (11) and (14) from pp. 16 and 17 in the       *
' working paper.                                                                                 *
' ************************************************************************************************

smpl %date_begin_q %date_end_q
series e_diffe = re_diffe * ehhcfe
series etotalfe = ehhcfe + e_diffe

for %variable_list enfb_empfe _
                   enfb_propuffe _
                   efarmfe _
                   esvhhhfe _
                   esvhnpfe _
                   egfcfe _
                   egfm_afe _
                   egfm_rfe _
                   egslfe
     series {%variable_list} = etotalfe * r{%variable_list}
next

series enfbfe = enfb_empfe + enfb_propuffe
series esvhfe = esvhhhfe + esvhnpfe
series egfmfe = egfm_afe + egfm_rfe
series egffe = egfcfe + egfmfe
series egfe = egffe + egslfe

     e_diffe.label(d)        Potential Difference, BLS and H.H. Survey Employment (Millions)
     etotalfe.label(d)       Potential BLS Employment (Millions)
     enfb_empfe.label(d)     Potential Employment, NFB Employees (Millions)
     enfb_propuffe.label(d)  Potential Employment, NFB Proprietors & Unpaid Family (Millions)
     enfbfe.label(d)         Potential Employment, NFB (Millions)
     efarmfe.label(d)        Potential Employment, Farm Sector (Millions)
     esvhhhfe.label(d)       Potential Employment, Household Sector (Millions)
     esvhnpfe.label(d)       Potential Employment, Nonprofit Sector (Millions)
     esvhfe.label(d)         Potential Employment, Households & Nonprofits (Millions)
     egfcfe.label(d)         Potential Employment, Federal Government, Civilian (Millions)
     egfm_afe.label(d)       Potential Employment, Federal Government, Armed Forces (Millions)
     egfm_rfe.label(d)       Potential Employment, Federal Government, A.F. Reserve (Millions)
     egfmfe.label(d)         Potential Employment, Federal Government, Military (Millions)
     egslfe.label(d)         Potential Employment, State & Local Government (Millions)
     egffe.label(d)          Potential Employment, Federal Goverment (Millions)
     egfe.label(d)           Potential Employment, Government (Millions)

' ************************************************************************************************
' ***                     Estimate Potential Sectoral Average Weekly Hours                     ***
'                                                                                                *
' The code in this section calculates average weekly hours worked by various groups in the       *
' several sectors and estimates potential average weekly hours for those groups using equations  *
' similar to those used above for estimating sectoral employment shares, as discussed on         *
' pp. 17-18 of the working paper (the equations below are of the form of equation (15) in the    *
' working paper).                                                                                *
'                                                                                                *
' ************************************************************************************************

smpl %date_begin_q %date_end_q
for %variable_list nfb_emp _
                   nfb_propuf _
                   farm _
                   svhhh _
                   svhnp _
                   gfc _
                   gfm_a _
                   gfm_r _
                   gsl
     series mhe{%variable_list} = (mh{%variable_list} / e{%variable_list}) * 1000 / 52
     %dependent_variable_list = "mhe" + %variable_list
     series ln_{%dependent_variable_list} = log({%dependent_variable_list})
     equation eq_{%dependent_variable_list}.ls ln_{%dependent_variable_list} _
        c empgap empgap-empgap(-1) Trend_1948_1953 _
        Trend_1953_1957 Trend_1957_1960 Trend_1960_1969 _
        Trend_1969_1973 Trend_1973_1980 Trend_1980_1990 _
        Trend_1990_2001 Trend_2001
     eq_{%dependent_variable_list}.fit {%dependent_variable_list}_hat
     series {%dependent_variable_list}fe = exp({%dependent_variable_list}_hat _
                 - (empgap * eq_{%dependent_variable_list}.@coefs(2)) _
                 - ((empgap-empgap(-1)) * eq_{%dependent_variable_list}.@coefs(3)))
     graph gr_{%dependent_variable_list}_est.line _
                 {%dependent_variable_list} {%dependent_variable_list}fe
next

     mhenfb_emp.label(d)      Average Weekly Hours Worked, Nonfarm Business Employees
     mhenfb_propuf.label(d)   Average Weekly Hours Worked, NFB Proprietors & Unpaid Fam.
     mhefarm.label(d)         Average Weekly Hours Worked, Farm Sector
     mhesvhhh.label(d)        Average Weekly Hours Worked, Household Sector
     mhesvhnp.label(d)        Average Weekly Hours Worked, Nonprofit Sector
     mhegfc.label(d)          Average Weekly Hours Worked, Federal Government, Civilian
     mhegfm_a.label(d)        Average Weekly Hours Worked, Federal Government, Armed Forces
     mhegfm_r.label(d)        Average Weekly Hours Worked, Federal Government, Reserve
     mhegsl.label(d)          Average Weekly Hours Worked, State & Local Government

     mhenfb_empfe.label(d)    Potential Average Weekly Hours, NFB Employees
     mhenfb_propuffe.label(d) Potential Average Weekly Hours, NFB Proprietors & Unpaid Family
     mhefarmfe.label(d)       Potential Average Weekly Hours, Farm Sector
     mhesvhhhfe.label(d)      Potential Average Weekly Hours, Household Sector
     mhesvhnpfe.label(d)      Potential Average Weekly Hours, Nonprofit Sector
     mhegfcfe.label(d)        Potential Average Weekly Hours, Federal Government Civilians
     mhegfm_afe.label(d)      Potential Average Weekly Hours, Federal Government Armed Forces
     mhegslfe.label(d)        Potential Average Weekly Hours, State & local

' Create figures of the results
graph gr_mhenfb_emp mhenfb_emp mhenfb_empfe
graph gr_mhenfb_propuf mhenfb_propuf mhenfb_propuffe
graph gr_mhefarm mhefarm mhefarmfe
graph gr_mhesvhhh mhesvhhh mhesvhhhfe
graph gr_mhesvhnp mhesvhnp mhesvhnpfe
graph gr_mhegfc mhegfc mhegfcfe
graph gr_mhegfm_a mhegfm_a mhegfm_afe
graph gr_mhegsl mhegsl mhegslfe

' ************************************************************************************************
' ***                         Calculate Potential Sectoral Total Hours                         ***
'                                                                                                *
' This code calculates potential sectoral total hours using equation (16) on page 17 of the      *
' working paper.                                                                                 *
'                                                                                                *
' ************************************************************************************************

for %variable_list nfb_emp _
                   nfb_propuf _
                   farm _
                   svhhh _
                   svhnp _
                   gfc _
                   gfm_a _
                   gsl
     series mh{%variable_list}fe = e{%variable_list}fe * mhe{%variable_list}fe * 52 / 1000
next

series mhgfm_rfe = egfm_rfe * mhegfm_r * 52 / 1000
series mhnfbfe = mhnfb_empfe + mhnfb_propuffe
series mhenfbfe = mhnfbfe/ (enfbfe * 0.001 * 52)
series mhsvhfe = mhsvhhhfe + mhsvhnpfe
series mhgfmfe = mhgfm_afe + mhgfm_rfe
series mhgffe = mhgfcfe + mhgfmfe
series mhgfe = mhgffe + mhgslfe
series mhtotalfe = mhnfbfe _
                 + mhfarmfe _
                 + mhsvhhhfe _
                 + mhsvhnpfe _
                 + mhgffe _
                 + mhgslfe

     mhnfb_empfe.label(d)    Potential Hours, NFB Employees (Billions)
     mhnfb_propuffe.label(d) Potential Hours, NFB Proprietors & Unpaid Family (Billions)
     mhnfbfe.label(d)        Potential Hours, NFB (Billions)
     mhfarmfe.label(d)       Potential Hours, Farm Sector (Billions)
     mhsvhhhfe.label(d)      Potential Hours, Household Sector (Billions)
     mhsvhnpfe.label(d)      Potential Hours, Nonprofit Sector (Billions)
     mhsvhfe.label(d)        Potential Hours, Households & Nonprofits (Billions)
     mhgfcfe.label(d)        Potential Hours, Federal Government, Cvilian (Billions)
     mhgfm_afe.label(d)      Potential Hours, Federal Government, Active-Duty Military (Billions)
     mhgfm_rfe.label(d)      Potential Hours, Federal Government, Reserve Military (Billions)
     mhgfmfe.label(d)        Potential Hours, Federal Government, Military (Billions)
     mhgslfe.label(d)        Potential Hours, State & Local Government (Billions)
     mhgffe.label(d)         Potential Hours, Federal Goverment (Billions)
     mhgfe.label(d)          Potential Hours, Government (Billions)
     mhtotalfe.label(d)      Potential Total Hours (Billions)
     mhenfbfe.label(d)       Potential Average Weekly Hours, NFB

graph gr_etotal etotal etotalfe
graph gr_enfb enfb enfbfe
graph gr_efarm efarm efarmfe
graph gr_esvhhh esvhhh esvhhhfe
graph gr_esvhnp esvhnp esvhnpfe
graph gr_egf egfc+egfm egffe
graph gr_egsl egsl egslfe
graph gr_mhtotal mhtotal mhtotalfe
graph gr_mhnfb mhnfb mhnfbfe
graph gr_mhfarm mhfarm mhfarmfe
graph gr_mhsvhhh mhsvhhh mhsvhhhfe
graph gr_mhsvhnp mhsvhnp mhsvhnpfe
graph gr_mhgf mhgfc+mhgfm mhgffe
graph gr_mhgsl mhgsl mhgslfe

' ************************************************************************************************
'                A handful of additional actual values for nonfarm business:                     *
' ************************************************************************************************

series mhnfb = mhnfb_emp + mhnfb_propuf
     mhnfb.label(d)          Hours Worked, Nonfarm Business (Billions)
series mhnfbconst =  @elem(mhnfb, {%base_year})
     mhnfbconst.label(d)     Hours Worked, Nonfarm Business, Base Year = {%base_year}
series ilab = (mhnfb / mhnfbconst)
     ilab.label(d)           Index, Nonfarm Business Labor Input ({%base_year} = 1.0)

' ************************************************************************************************
' ***         Estimate Components of Potential Output in the Nonfarm Business Sector           ***
'                                                                                                *
' The code in this section estimates annual potential output in nonfarm business using a         *
' Cobb-Douglas production function (equation (3) in the working paper) in log form:              *
'                                                                                                *
'      log(Potential NFB Output) = Capital Share * log(Index of NFB Capital Services)            *
'                                + Labor Share * log(Index of Potental NFB Hours)                *
'                                + log(Index of Potential NFB Total Factor Productivity)         *
'                                + a constant                                                    *
'                                                                                                *
' Potential NFB hours are already estimated above, so the code in this section:                  *
'  (1) calculates the capital and labor shares, which sum to 1.0,                                *
'  (2) estimates an index of NFB capital services (the 'capital input' or ICAP) using the        *
'      Jorgenson-Hall approach,                                                                  *
'  (3) backs out a residual index of total factor productivity                                   *
'      (iprod or "A", as per equation (20) in the working paper), and                            *
'  (4) estimates a potential productivity series (IPRODFE).                                      *
'                                                                                                *
' For further details see pp. 19-28 of the working paper.                                        *
'                                                                                                *
' ************************************************************************************************

pageselect Annual

' ************************************************************************************************
'                                 (1)   Calculate factor shares                                  *
' ************************************************************************************************

smpl %date_begin_a %date_end_a
series yndomnfb = gdpnfb _
                - ccanfb _
                - ibtnfb _
                - stat
     yndomnfb.label(d) Net Domestic NFB Income ($Billions)

' ************************************************************************************************
'                Raw capital share -- equation (21) from the working paper                       *
'                                                                                                *
' NOTE: The series is normally smoothed using a HodrickPrescott filter. However, the latest     *
' values of the smoothed historical series are partly dependent on values that are projected for *
' years beyond the historical period and that are not provided here. The values that are         *
' actually estimated (kshare) have been provided separately in the data inputs and the model     *
' code is included for completeness.                                                             *
'                                                                                                *
' The code that is normally used to create the smoothed kshare series (based on kshare_input,    *
' with projected data) is:                                                                       *
'                                                                                                *
'   hpf(lambda = 100) kshare_input kshare                                                        *
'                                                                                                *
' ************************************************************************************************

series kshare_input = 1.0 - (wssnfb) / (gdpnfb - stat - ibtnfb - yentnfbadj)
     kshare_input.label(d) Raw Capital Income Share

series yknfb = yndomnfb-(wssnfb+((1-kshare_input)*yentnfbadj))
     yknfb.label(d) Net Capital Income, NFB ($Billions)

' ************************************************************************************************
' ***                    (2) Estimate an Index of NFB Capital Services (ICAP)                  ***
'                                                                                                *
' The bulk of the calculations in this section involve calculating rental shares, which are      *
' used as weights for the different types of NFB capital in calculating the index. The equations *
' are of the following form, as per equation (26) on p. 24 of the working paper:                 *
'                                                                                                *
' SHARE(x) = [rate of return + depreciation rate(x) + rate of expected capital gain(x)]          *
'          * [(1 - investment tax credit rate                                                    *
'                - (corporate tax rate * PDV of a dollar of tax depreciation))                   *
'                / (1 - corporate tax rate)]                                                     *
'          * price index(x)                                                                      *
'          * (real capital stock(x) / total nominal capital income)                              *
'                                                                                                *
' The rate of return is calculated by taking the sum of the share equations and solving for it.  *
' (See equation (28) in the working paper.)                                                      *
'                                                                                                *
' ************************************************************************************************

' ************************************************************************************************
' ***                              Calculate Depreciation Rates                                ***
' ************************************************************************************************

smpl %date_begin_a %date_end_a
for %variable_list eqc _
                   comm _
                   oth
     series dipdenr{%variable_list} = qccapdenrnf{%variable_list} / qknipdenrnf{%variable_list}(-1)
next

for %variable_list sft _
                   rad _
                   ela
     series diippnr{%variable_list} = qccaippnrnf{%variable_list} / qkniippnrnf{%variable_list}(-1)
next

series dicnr = qccacnrnf / qknicnrnf(-1)
series difixr = qccafixr / qknifixr(-1)

     dipdenreqc.label(d)  Depreciation Rate, NFB Computer Equipment
     dipdenrcomm.label(d) Depreciation Rate, NFB Communications Equipment
     dipdenroth.label(d)  Depreciation Rate, NFB Other Equipment
     diippnrsft.label(d)  Depreciation Rate, NFB Software
     diippnrrad.label(d)  Depreciation Rate, NFB Research & Development
     diippnrela.label(d)  Depreciation Rate, NFB Entertainment, Literary & Artistic
     dicnr.label(d)       Depreciation Rate, NFB Nonresidential Structures
     difixr.label(d)      Depreciation Rate, NFB Residential Structures

' Extend some rates back at constant rates

smpl %date_begin_a "1966"
series dipdenreqc = @elem(dipdenreqc, "1967")
series dipdenroth = @elem(dipdenroth, "1967")
series dicnr = @elem(dicnr, "1967")

' ************************************************************************************************
' ***                                   Calculate Tax Terms                                    ***
' ************************************************************************************************

smpl %date_begin_a %date_end_a
for %variable_list str _
                   eqc _
                   comm _
                   sft _
                   rad _
                   ela
     series tax{%variable_list} = (1 - itc{%variable_list} _
                                     - (rtcorp * pdvcca{%variable_list})) _
                                / (1 - rtcorp)
next

series taxoth  = (1 - itceqo - (rtcorp * pdvccaeqo)) / (1 - rtcorp)
series taxinv  = 1 / (1 - rtcorp)
series taxfixr = taxstr
series taxland = 1 / (1 - rtcorp)

smpl "1947" "1951"
for %variable_list str _
                   eqc _
                   comm _
                   oth _
                   sft _
                   rad _
                   ela _
                   land _
                   inv _
                   fixr
     series tax{%variable_list} = @elem(tax{%variable_list}, "1952")
next

     taxstr.label(d) Tax Term, NFB Nonresidential Structures
     taxeqc.label(d) Tax Term, NFB Computer Equipment
     taxcomm.label(d) Tax Term, NFB Communications Equipment
     taxoth.label(d) Tax Term, NFB Other Equipment
     taxsft.label(d) Tax Term, NFB Software
     taxrad.label(d) Tax Term, NFB Research & Development
     taxela.label(d) Tax Term, NFB Entertainment, Literary & Artistic
     taxland.label(d) Tax Term, NFB Land
     taxinv.label(d) Tax Term, NFB Inventories
     taxfixr.label(d) Tax Term, NFB Rental Residential Structures

' ************************************************************************************************
' ***                       Calculate Expected Price Appreciation Terms                        ***
' ************************************************************************************************

' Number of years of lagged price terms for expectations term in rental price equations
!exp_lags = 5

smpl %date_begin_a %date_end_a    
series rentprop = knifixrr / (knifixrr + knifixro)
     rentprop.label(d) Tenant-Occupied Portion of Total Real Housing Stock

for %variable_list cnrnf _
                   fixr _
                   pdenrnfeqc _
                   pdenrnfcomm _
                   pdenrnfoth _
                   ippnrnfsft _
                   ippnrnfrad _
                   ippnrnfela
     for !i = 1 to (!exp_lags - 1)
          if !i = 1 then
               smpl {%date_begin_a}+!i {%date_begin_a}+!i
               series expp{%variable_list} = @pch((kni{%variable_list} _
                                           / qkni{%variable_list}) / pgdp)
          else
               smpl {%date_begin_a}+!i {%date_begin_a}+!i
               series expp{%variable_list} = @movav(@pch((kni{%variable_list} _
                                           / qkni{%variable_list}) / pgdp), !i)
          endif
     next

     smpl {%date_begin_a}+!exp_lags %date_end_a
     series expp{%variable_list} = @movav(@pch((kni{%variable_list} _
                                 / qkni{%variable_list}) / pgdp), !exp_lags)
     
     smpl %date_begin_a %date_end_a
     graph gr_expp{%variable_list}.line expp{%variable_list}
next

for !i = 1 to (!exp_lags-1)
     if !i = 1 then
          smpl {%date_begin_a}+!i {%date_begin_a}+!i
          series exppinv = @pch((invnf / qinvnf) / pgdp)
     else
          smpl {%date_begin_a}+!i {%date_begin_a}+!i
          series exppinv = @movav(@pch((invnf / qinvnf) / pgdp), !i)
     endif
next

smpl {%date_begin_a}+!exp_lags %date_end_a
series exppinv = @movav(@pch((invnf / qinvnf) / pgdp), !exp_lags)

smpl %date_begin_a %date_end_a
graph gr_exppinv.line exppinv

     exppcnrnf.label(d) Expected Price Appreciation Term, NFB Nonresidential Structures
     exppfixr.label(d) Expected Price Appreciation Term, NFB Residential Structures
     expppdenrnfeqc.label(d) Expected Price Appreciation Term, NFB Computer Equipment
     expppdenrnfcomm.label(d) Expected Price Appreciation Term, NFB Communications Equipment
     expppdenrnfoth.label(d) Expected Price Appreciation Term, NFB Other Equipment
     exppippnrnfsft.label(d) Expected Price Appreciation Term, NFB Software
     exppippnrnfrad.label(d) Expected Price Appreciation Term, NFB Research & Development
     exppippnrnfela.label(d) Expected Price Appreciation Term, NFB Entertainment, Literary & Art.
     exppinv.label(d) Expected Price Appreciation Term, NFB Inventories

' ************************************************************************************************
' ***              Calculate an Implicit Internal Rate of Return (Equation (28))               ***
' ************************************************************************************************

smpl %date_begin_a %date_end_a
for %variable_list eqc _
                   comm _
                   oth
     series denom_{%variable_list} = knipdenrnf{%variable_list}(-1) * tax{%variable_list}
     series num_{%variable_list} = denom_{%variable_list} * _
                                      (dipdenr{%variable_list} - expppdenrnf{%variable_list})
next

for %variable_list sft _
                   rad _
                   ela
     series denom_{%variable_list} = kniippnrnf{%variable_list}(-1) * tax{%variable_list}
     series num_{%variable_list} = denom_{%variable_list} _
                                 * (diippnr{%variable_list} - exppippnrnf{%variable_list})
next

series denom_str = knicnrnf(-1) * taxstr
series num_str = denom_str * (dicnr - exppcnrnf)

series denom_tor = rentprop * knifixr(-1) * taxfixr
series num_tor = denom_tor * (difixr - exppfixr)

smpl %date_estimate_begin %date_end_a
series denom_lnd = kniland(-1) * taxland

smpl "1948" "1948"
series denom_lnd = denom_lnd(+1) * denom_lnd(+1) / denom_lnd(+2)

smpl %date_begin_a %date_end_a
series num_lnd = denom_lnd * (-exppfixr)
series denom_inv = invnf * taxinv
series num_inv = denom_inv * (-exppinv)

     denom_eqc.label(d)  Partial Denominator Term, ROR Calculation, NFB Computer Equipment
     denom_comm.label(d) Partial Denominator Term, ROR Calculation, NFB Communications Equipment
     denom_oth.label(d)  Partial Denominator Term, ROR Calculation, NFB Other Equipment
     denom_sft.label(d)  Partial Denominator Term, ROR Calculation, NFB Software
     denom_rad.label(d)  Partial Denominator Term, ROR Calculation, NFB Research & Development
     denom_ela.label(d)  Partial Denominator Term, ROR Calculation, NFB Entertainment, Lit. & Art.
     denom_str.label(d)  Partial Denominator Term, ROR Calculation, NFB Nonresidential Structures
     denom_tor.label(d)  Partial Denominator Term, ROR Calculation, NFB Rental Residential Str.
     denom_lnd.label(d)  Partial Denominator Term, ROR Calculation, NFB Land
     denom_inv.label(d)  Partial Denominator Term, ROR Calculation, NFB Inventories
     num_eqc.label(d)    Partial Numerator Term, ROR Calculation, NFB Computer Equipment
     num_comm.label(d)   Partial Numerator Term, ROR Calculation, NFB Communications Equipment
     num_oth.label(d)    Partial Numerator Term, ROR Calculation, NFB Other Equipment
     num_sft.label(d)    Partial Numerator Term, ROR Calculation, NFB Software
     num_rad.label(d)    Partial Numerator Term, ROR Calculation, NFB Research & Development
     num_ela.label(d)    Partial Numerator Term, ROR Calculation, NFB Entertainment, Lit. & Art.
     num_str.label(d)    Partial Numerator Term, ROR Calculation, NFB Nonresidential Structures
     num_tor.label(d)    Partial Numerator Term, ROR Calculation, NFB Rental Residential Str.
     num_lnd.label(d)    Partial Numerator Term, ROR Calculation, NFB Land
     num_inv.label(d)    Partial Numerator Term, ROR Calculation, NFB Inventories

smpl %date_begin_a %date_end_a
series num_total = yknfb + ccanfb + (rentprop * ccafixr)
series denom_total = 0.0

for %variable_list eqc _
                   comm _
                   oth _
                   sft _
                   rad _
                   ela _
                   str _
                   tor _
                   lnd _
                   inv
     series num_total = num_total - num_{%variable_list}
     series denom_total = denom_total + denom_{%variable_list}
next

     num_total.label(d) Numerator, Implicit Internal Rate of Return Calculation
     denom_total.label(d) Denominator, Implicit Internal Rate of Return Calculation

series rror = num_total / denom_total
     rror.label(d) Implicit Internal Rate of Return to Capital, NFB

' ************************************************************************************************
' ***                Calculate Rental Shares for Capital Services (Equation (28))              ***
' ************************************************************************************************

smpl %date_begin_a %date_end_a
series sharetotal = 0.0

for %variable_list eqc _
                   comm _
                   oth
     series rspdenrnf{%variable_list} = (rror _
                                      + dipdenr{%variable_list} _
                                      - expppdenrnf{%variable_list}) _
                                      * tax{%variable_list} _
                                      * knipdenrnf{%variable_list}(-1)
     series sharetotal = sharetotal + rspdenrnf{%variable_list}
next

for %variable_list sft _
                   rad _
                   ela
     series rsippnrnf{%variable_list} = (rror _
                                      + diippnr{%variable_list} _
                                      - exppippnrnf{%variable_list}) _
                                      * tax{%variable_list} _
                                      * kniippnrnf{%variable_list}(-1)
     series sharetotal = sharetotal + rsippnrnf{%variable_list}
next

series rscnrnf = (rror + dicnr - exppcnrnf) * taxstr * knicnrnf(-1)
series sharetotal = sharetotal + rscnrnf

series rsfixr = (rror + difixr - exppfixr) * taxfixr * knifixr(-1) * rentprop
series sharetotal = sharetotal + rsfixr

smpl %date_begin_a %date_end_a
series rsinv = (rror - exppinv) * taxinv * invnf
series sharetotal = sharetotal + rsinv

' ************************************************************************************************
'                               Do LAND last to back out share in 1948                           *
' ************************************************************************************************

smpl %date_estimate_begin %date_end_a
series rsland = (rror - exppfixr) * taxland * kniland(-1)

smpl "1948" "1948"
series rsland = (yknfb + ccanfb + (rentprop * ccafixr)) - sharetotal

smpl %date_begin_a %date_end_a
series sharetotal = sharetotal + rsland

     rscnrnf.label(d)       Share of NFB Capital Income, Nonresidential Structures ($Billions)
     rsfixr.label(d)        Share of NFB Capital Income, Rental Residential Structures ($Billions)
     rsland.label(d)        Share of NFB Capital Income, Land ($Billions)
     rspdenrnfeqc.label(d)  Share of NFB Capital Income, Computer Equipment ($Billions)
     rspdenrnfcomm.label(d) Share of NFB Capital Income, Communications Equipment ($Billions)
     rspdenrnfoth.label(d)  Share of NFB Capital Income, Other Equipment ($Billions)
     rsippnrnfsft.label(d)  Share of NFB Capital Income, Software ($Billions)
     rsippnrnfrad.label(d)  Share of NFB Capital Income, Research & Development ($Billions)
     rsippnrnfela.label(d)  Share of NFB Capital Income, Entertainment, Literary & Art. ($Billions)
     rsinv.label(d)         Share of NFB Capital Income, Inventories ($Billions)
     sharetotal.label(d)    Gross NFB Capital Income ($Billions)

smpl %date_begin_a %date_end_a
series sharestr = rscnrnf / sharetotal
series sharetor = rsfixr / sharetotal
series sharelnd = rsland / sharetotal
series shareeqc = rspdenrnfeqc / sharetotal
series sharecomm = rspdenrnfcomm / sharetotal
series shareoth = rspdenrnfoth / sharetotal
series sharesft = rsippnrnfsft / sharetotal
series sharerad = rsippnrnfrad / sharetotal
series shareela = rsippnrnfela / sharetotal
series shareinv = rsinv / sharetotal

     sharestr.label(d)  Share of NFB Capital Income, Nonresidential Structures (Fraction)
     sharetor.label(d)  Share of NFB Capital Income, Rental Residential Structures (Fraction)
     sharelnd.label(d)  Share of NFB Capital Income, Land (Fraction)
     shareeqc.label(d)  Share of NFB Capital Income, Computer Equipment (Fraction)
     sharecomm.label(d) Share of NFB Capital Income, Communications Equipment (Fraction)
     shareoth.label(d)  Share of NFB Capital Income, Other Equipment (Fraction)
     sharesft.label(d)  Share of NFB Capital Income, Software (Fraction)
     sharerad.label(d)  Share of NFB Capital Income, Research & Development (Fraction)
     shareela.label(d)  Share of NFB Capital Income, Entertainment, Literary & Art. (Fraction)
     shareinv.label(d)  Share of NFB Capital Income, Inventories (Fraction)

' ************************************************************************************************
' ***                   Calculate the NFB Capital Input from the Components                    ***
'                                                                                                *
' First, calculate two-period moving average rental shares (equation (24) in the working paper)  *
' and then calculate the Tornqvist Index using the two-period averages (equation (23) in the     *
' working paper).                                                                                *
' ************************************************************************************************

smpl %date_begin_a %date_end_a
for %variable_list eqc comm oth sft rad ela str lnd tor inv
     series sharebar{%variable_list} = @movav(share{%variable_list}, 2)
next

     sharebarstr.label(d) Two-year Average Rental Share, Nonresidential Structures (Fraction)
     sharebartor.label(d) Two-year Average Rental Share, Rental Residential Structures (Fraction)
     sharebarlnd.label(d) Two-year Average Rental Share, Land (Fraction)
     sharebareqc.label(d) Two-year Average Rental Share, Computer Equipment (Fraction)
     sharebarcomm.label(d) Two-year Average Rental Share, Communications Equipment (Fraction)
     sharebaroth.label(d) Two-year Average Rental Share, Other Equipment (Fraction)
     sharebarsft.label(d) Two-year Average Rental Share, Software (Fraction)
     sharebarrad.label(d) Two-year Average Rental Share, Research & Development (Fraction)
     sharebarela.label(d) Two-year Average Rental Share, Entertainment, Literary & Art. (Fraction)
     sharebarinv.label(d) Two-year Average Rental Share, Inventories (Fraction)

series temporary_1 = exp((sharebareqc * log (qknipdenrnfeqc / qknipdenrnfeqc(-1))) _
                   + (sharebarcomm * log (qknipdenrnfcomm / qknipdenrnfcomm(-1))) _
                   + (sharebaroth * log (qknipdenrnfoth / qknipdenrnfoth(-1))) _
                   + (sharebarsft * log (qkniippnrnfsft / qkniippnrnfsft(-1))) _
                   + (sharebarrad * log (qkniippnrnfrad / qkniippnrnfrad(-1))) _
                   + (sharebarela * log (qkniippnrnfela / qkniippnrnfela(-1))) _
                   + (sharebarstr * log (qknicnrnf / qknicnrnf(-1))) _
                   + (sharebarlnd * log (qkniland / qkniland(-1))) _
                   + (sharebartor * log ((rentprop * qknifixr) / (rentprop(-1) * qknifixr(-1)))) _
                   + (sharebarinv * log (qinvnf / qinvnf(-1))) )

smpl "1948" %date_end_a
series temporary_2 = 1

smpl %date_estimate_begin %date_end_a
series temporary_2 = temporary_2(-1) * temporary_1

smpl %date_begin_a %date_end_a
series icap = temporary_2 / @elem(temporary_2, {%base_year})
    icap.label(d) Index of Capital Services, Nonfarm Business ({%base_year} = 1.0)
delete temporary_1 temporary_2

' ************************************************************************************************
' ***                       (End of Index of NFB Capital Services Section)                     ***
' ************************************************************************************************

' ************************************************************************************************
' ***                      (3) Calculate NFB Total Factor Productivity                         ***
' ***                      (iprod, equation (20) in the Working Paper)                         ***
' ***                  and Estimate Potential TFP (iprodfe, equation (29))                     ***
' ************************************************************************************************

smpl %date_estimate_begin %date_end_a

' ************************************************************************************************
'                        Calculate actual total factor productivity                              *
' ************************************************************************************************

copy Quarterly\mhnfb mhnfb
series mhnfbconst =  @elem(mhnfb, {%base_year})
series ilab = (mhnfb / mhnfbconst)
series ioutput = qgdpnfb / exp((kshare * log(icap(-1))) + ((1 - kshare) * log(ilab)))
series iprod  = ioutput / @elem(ioutput, {%base_year})
series gdpconst = log(qgdpnfb) - (kshare * log(icap(-1)) + (1 - kshare) * log(ilab) + log(iprod))
series temporary_x = @elem(gdpconst, {%base_year})
series gdpconst = temporary_x

delete ioutput temporary_x

     mhnfbconst.label(d) Hours Worked, Nonfarm Business, Base Year = {%base_year}
     ilab.label(d) Index of Labor Input, Nonfarm Business ({%base_year} = 1.00)
     iprod.label(d) Total Factor Productivity ({%base_year} = 1.0)     
     gdpconst.label(d) Constant, Log Equation for Gross Domestic Product     
     
     
' ************************************************************************************************
'                       (4) Estimate potential total factor productivity                         *
'                                                                                                *
' Actual TFP (iprod) is calculated at an annual frequency, and the series is interpolated to a   *
' quarterly frequency using the BLS series for NFB labor productivity (real output per hour) as  *
' a pattern series. The interpolation is performed using the "Denton-Cholette" or                *
' "Dagum-Cholette" first difference disaggregation method, using publically available EViews     *
' code orignally posted as cholette_uni.prg and agg_help.prg on the EViews User Forum at         *
' forums.eviews.com/viewtopic.php?t=1342 and included as three distinct programs here. The       *
' routines are included in the statements below.                                                 *
' ************************************************************************************************

include subroutine_cholette.prg
include subroutine_aggregation.prg
include subroutine_dif.prg

pageselect Quarterly

smpl "1949Q1" {%date_end_a_last_q}
copy(c = d) Annual\iprod iprod_uni
series lxnfa1 = lxnfa
smpl %date_begin_q "1948Q4"
series lxnfa1 = na

smpl "1949Q1" {%date_end_a_last_q}
series iprod
     iprod.label(d) Total Factor Productivity ({%base_year} = 1.0)

call cholette_uni(iprod_uni, iprod, lxnfa1, 2, 1, 4, 1)
delete iprod_uni lxnfa1

' ************************************************************************************************
' Extend TFP into the last, incomplete year by regressing historical TFP growth on the growth    *
' of BLS labor productivity and using the estimated parameter to extend TFP growth based on      *
' recent growth of labor productivity.                                                           *
' ************************************************************************************************

smpl "1949Q2" {%date_end_a_last_q}
series pct_iprod = (iprod / iprod(-1)) - 1
series pct_lxnfa = (lxnfa / lxnfa(-1)) - 1
equation eq_pct_iprod_49.ls pct_iprod c pct_lxnfa

smpl {%date_end_a_last_q}+1 %date_end_q
series pct_lxnfa = (lxnfa / lxnfa(-1)) - 1
series iprod = iprod(-1) * (1 + eq_pct_iprod_49.@coefs(1) + _
               (eq_pct_iprod_49.@coefs(2) * pct_lxnfa))

' ************************************************************************************************
' Estimate potential TFP. This equation includes an additional time trend for the IT-related     *
' productivity jump in the late 1990s and early 2000s. Breakpoints for the IT trend were         *
' calculated outside the model by determining which breaks result in the largest adjusted        *
' R-square in the equation below.                                                                *
' ************************************************************************************************

smpl @all
for %dependent_variable_list iprod
     series ln_{%dependent_variable_list} = log({%dependent_variable_list})
     
     smpl 1948Q4 %date_end_q
     equation equation_{%dependent_variable_list}.ls ln_{%dependent_variable_list} _
          c empgap (empgap-empgap(-1)) Trend_1948_1953 _
          Trend_1953_1957 Trend_1957_1960 Trend_1960_1969 _
          Trend_1969_1973 Trend_1973_1980 Trend_1980_1981 _
          Trend_1981_1990 Trend_1990_2001 Trend_1997_2005 Trend_2001
     equation_{%dependent_variable_list}.fit {%dependent_variable_list}_hat
     series {%dependent_variable_list}fe = exp({%dependent_variable_list}_hat _
                         - (empgap * equation_{%dependent_variable_list}.@coefs(2)) _
                         - ((empgap-empgap(-1)) * equation_{%dependent_variable_list}.@coefs(3)))
next

     iprodfe.label(d) Potential Total Factor Productivity (Actual {%base_year} = 1.0)

smpl "1990Q4" %date_end_q
graph gr_iprod_est.line iprod iprodfe

' ************************************************************************************************
' ***                             (End of Nonfarm Business Section)                            ***
' ************************************************************************************************

' ************************************************************************************************
' ***                 Estimate Potential Labor Productivity in Four Sectors:                   ***
'                                                                                                *
'                            Farms (Equation (31)),                                              *
'                            Nonprofits (Equation (31)),                                         *
'                            Federal Government (Equation (36)), and                             *
'                            State & Local Government (Equation (37))                            *
' ************************************************************************************************

smpl %date_begin_q %date_end_q
series jaf = qgdpaf / mhfarm
series jsvhnp = qgdpsvhnp / mhsvhnp
series jgfc = qgfowss / mhgfc
series jgfm = qgfmlwss / mhgfm
series jgsl = qgslwss / mhgsl

     jaf.label(d)            Labor productivity, agriculture ($2009 per hour)
     jsvhnp.label(d)         Labor productivity, non-profit sector ($2009 per hour)
     jgfc.label(d)           Labor productivity, Federal government, civilian ($2009 per hour)
     jgfm.label(d)           Labor productivity, Federal government, civilian ($2009 per hour)     
     jgsl.label(d)           Labor productivity, state & local governments ($2009 per hour)

smpl "1948Q4" %date_end_q
for %dependent_variable_list jaf jsvhnp jgsl
     series ln_{%dependent_variable_list} = log({%dependent_variable_list})
     equation equation_{%dependent_variable_list}.ls ln_{%dependent_variable_list} _
        c Trend_1948_1953 Trend_1953_1957 Trend_1957_1960 _
        Trend_1960_1969 Trend_1969_1973 Trend_1973_1980 _
        Trend_1980_1990 Trend_1990_2001 Trend_2001
     equation_{%dependent_variable_list}.fit {%dependent_variable_list}_hat
     series {%dependent_variable_list}fe = exp({%dependent_variable_list}_hat)
     graph gr_{%dependent_variable_list}_est.line _
                 {%dependent_variable_list} {%dependent_variable_list}fe
next   

     jaffe.label(d)    Potential Labor productivity, agriculture ($2009 per hour)
     jsvhnpfe.label(d) Potential labor productivity, non-profit sector ($2009 per hour)
     jgslfe.label(d)   Potential labor productivity, state & local governments ($2009 per hour)

smpl "1948Q4" %date_end_q
for %dependent_variable_list jgfc
     series ln_{%dependent_variable_list} = log({%dependent_variable_list})
     equation equation_{%dependent_variable_list}.ls ln_{%dependent_variable_list} _
        c dummy_census Trend_1948_1953 Trend_1953_1957 Trend_1957_1960 _
        Trend_1960_1969 Trend_1969_1973 Trend_1973_1980 _
        Trend_1980_1990 Trend_1990_2001 Trend_2001
     equation_{%dependent_variable_list}.fit {%dependent_variable_list}_hat
     series {%dependent_variable_list}fe = exp({%dependent_variable_list}_hat _
                                - dummy_census * equation_{%dependent_variable_list}.@coefs(2))
     graph gr_{%dependent_variable_list}_est.line _
                 {%dependent_variable_list} {%dependent_variable_list}fe
next

     jgfcfe.label(d) Potential labor productivity, Federal government, civilian ($2009 per hour)

smpl "1948Q4" %date_end_q
for %dependent_variable_list jgfm
     series ln_{%dependent_variable_list} = log({%dependent_variable_list})
     equation equation_{%dependent_variable_list}.ls ln_{%dependent_variable_list} _
        c Trend_1948_1953 Trend_1953_1957 Trend_1957_1960 _
        Trend_1960_1969 Trend_1969_1973 Trend_1973_1980 _
        Trend_1980_1990 Trend_1990_2001 Trend_2001_2007 _
        Trend_2007
     equation_{%dependent_variable_list}.fit {%dependent_variable_list}_hat
     series {%dependent_variable_list}fe = exp({%dependent_variable_list}_hat)
     smpl "1970Q1" %date_end_q
     graph gr_{%dependent_variable_list}_est.line _
                 {%dependent_variable_list} {%dependent_variable_list}fe
next

     jgfmfe.label(d) Potential labor productivity, Federal government, military ($2009 per hour)

' ************************************************************************************************
' ***                 Calculate Return to Owner-Occupied Residential Housing                   ***
' ************************************************************************************************

pageselect Annual

smpl %date_estimate_begin %date_end_a
series jsvhhh=qgdpsvhhh/(qknifixr(-1)*(1-rentprop))
     jsvhhh.label(d) Rate of return to residential housing

' ************************************************************************************************
' ***                     Write Quarterly Estimates to the Annual Workpage                     ***
' ************************************************************************************************

pageselect Annual

smpl %date_begin_a %date_end_a
for %variable_list lcfe ehhcfe e_diffe etotalfe enfbfe enfb_empfe enfb_propuffe _
                   efarmfe esvhfe esvhhhfe esvhnpfe egffe egfcfe egfmfe egfm_afe egfm_rfe egslfe _
                   mhtotalfe mhnfbfe mhnfbfe mhnfb_empfe mhnfb_propuffe _
                   mhfarmfe mhsvhfe mhsvhhhfe mhsvhnpfe mhgffe mhgfcfe mhgfmfe mhgfm_afe _
                   mhgfm_rfe mhgslfe mhenfbfe mhenfb_empfe mhenfb_propuffe mhefarmfe mhesvhhhfe _
                   mhesvhnpfe mhegfcfe mhegfm_afe mhegslfe jaffe jsvhnpfe jgfcfe jgfmfe jgslfe _
                   renfb_empfe renfb_propuffe refarmfe resvhhhfe resvhnpfe regfcfe regfm_afe _
                   regfm_rfe regslfe iprodfe
     copy(c = na, merge, smpl = %date_begin_a + " " + %date_end_a) _
                                             Quarterly\{%variable_list} {%variable_list}
next

' ************************************************************************************************
'                  Apply Hodrick-Prescott filters to smooth several annual series:               *
'         1) the residuals from Fisher aggregation calculated at the beginning of the code       *
'                              2) return to owner-occupied housing                               *
' ************************************************************************************************

pageselect Annual

' 1) Smooth residuals from Fisher aggregation
smpl %date_begin_a %date_end_a
for %variable_list qgdp _
                   qgdpgf _
                   qgdpgsl _
                   qgdpg _
                   qgdpsvh
     {%variable_list}_res.hpf(lambda = 75) {%variable_list}_res_hp
     series {%variable_list}_resfe = {%variable_list}_res_hp
     graph gr_filtered_{%variable_list}_res.line _
                          {%variable_list}_res {%variable_list}_resfe
     delete {%variable_list}_res_hp
next

' 2) Smooth return to owner-occupied housing -- why %date_estimate_begin?
smpl %date_estimate_begin %date_end_a
for %variable_list jsvhhh
     {%variable_list}.hpf(lambda = 25) {%variable_list}_hp
     series {%variable_list}fe = {%variable_list}_hp
     graph gr_filtered_{%variable_list}.line _
                          {%variable_list} {%variable_list}fe
     delete {%variable_list}_hp
next

     jsvhhhfe.label(d) Potential rate of return to residential housing

smpl %date_estimate_begin %date_estimate_begin
series iprodfe = iprodfe(+1) * iprodfe(+1) / iprodfe(+2)

' *************************************************************************************************
' ***    Calculate Components of Potential Output and Aggregate to Total Potential Output       ***
'                                                                                                 *
' Sectoral output is aggregated up through various subtotals, with the Fisher residuals that were *
' calculated at the beginning of the program added to the totals.                                 *
' *************************************************************************************************

smpl %date_begin_a %date_end_a
series ilabfe = (mhnfbfe / mhnfbconst)
series qgdpaffe  = jaffe * mhfarmfe
series gdpaffe  = qgdpaffe * pgdpaf
series qgdpsvhhhfe  = jsvhhhfe * qknifixr(-1) * (1-rentprop)
series gdpsvhhhfe  = qgdpsvhhhfe * pgdpsvhhh
series qgdpsvhnpfe  = jsvhnpfe * mhsvhnpfe
series gdpsvhnpfe  = qgdpsvhnpfe * pgdpsvhnp

     ilabfe.label(d) Potential Index of Labor Input, Base Year = {%base_year}
     qgdpaffe.label(d) Real Potential Gross Value Added: Farm Business ($2009 Billions)
     gdpaffe.label(d) Potential Gross Value Added: Farm Business ($Billions)
     qgdpsvhhhfe.label(d) Real Potential Gross Value Added: Households ($2009 Billions)
     gdpsvhhhfe.label(d) Potential Gross Value Added: Households ($Billions)
     qgdpsvhnpfe.label(d) Real Potential Gross Value Added: Nonprofit Sector ($2009 Billions)
     gdpsvhnpfe.label(d) Potential Gross Value Added: Nonprofit Sector ($Billions)
     
' *************************************************************************************************
'                     Potential aggregate Household & Nonprofit sectoral GDP                      *
' *************************************************************************************************

group component_list gdpsvhhhfe gdpsvhnpfe
series gdpsvhfe = gdpsvhhhfe + gdpsvhnpfe
     gdpsvhfe.label(d) Potential Gross Value Added: Households & Institutions ($Billions)
series pgdpsvhhhfe = pgdpsvhhh
series pgdpsvhnpfe = pgdpsvhnp

call fisher_agg(component_list, gdpsvhfe, @pagefreq, %base_year, %date_estimate_begin, %date_end_a)
series qgdpsvhfe = qgdpsvhfe + qgdpsvh_resfe
     qgdpsvhfe.label(d) Real Potential Gross Value Added: Hholds. & Nonprofits ($2009 Billions)

delete pgdpsvhhhfe pgdpsvhnpfe

' *************************************************************************************************
'                                  Potential aggregate Federal GDP                                *
' *************************************************************************************************

smpl %date_begin_a %date_end_a
series qgfowssfe = jgfcfe * mhgfcfe
     qgfowssfe.label(d) Real Potential Compensation: Federal Nondefense ($2009 Billions)
series gfowssfe = qgfowssfe * pgfowss
     gfowssfe.label(d) Potential Compensation: Federal Nondefense($Billions)
series qgfmlwssfe = jgfmfe * mhgfmfe
     qgfmlwssfe.label(d) Real Potential Compensation: Natl Defense($2009 Billions)
series gfmlwssfe = qgfmlwssfe * pgfmlwss
     gfmlwssfe.label(d) Potential Compensation: Natl Defense ($Billions)
series gfwssfe = gfowssfe + gfmlwssfe
     gfwssfe.label(d) Potential Compensation, Federal Government Employees ($Billions)
     
group component_list gfowssfe gfmlwssfe
series pgfowssfe = pgfowss
     pgfowssfe.label(d) Potential Price Index, Compensation: Federal NonDef. ({%base_year} = 1.0)
series pgfmlwssfe = pgfmlwss
     pgfmlwssfe.label(d) Potential Price Index, Compensation: Federal Def. ({%base_year} = 1.0)

call fisher_agg(component_list, gfwssfe, @pagefreq, %base_year, %date_estimate_begin, %date_end_a)
     qgfwssfe.label(d) Real Potential Compensation of Federal Employees ($2009 Billions)

smpl %date_begin_a %date_end_a
group component_list gfwssfe gfocca gfmlcca
series gdpgffe = gfwssfe + gfocca + gfmlcca
     gdpgffe.label(d) Potential Gross Value Added: General Government: Federal ($Billions)
series pgfwssfe = pgfwss
     pgfwssfe.label(d) Potential Price Index, Compensation, Federal Government ({%base_year} = 1.0)

call fisher_agg(component_list, gdpgffe, @pagefreq, %base_year, %date_estimate_begin, %date_end_a)
series qgdpgffe = qgdpgffe + qgdpgf_resfe
     qgdpgffe.label(d) Real Potential Gross Value Added: Federal Government: ($2009 Billions)

' *************************************************************************************************
'                               Potential aggregate State & Local GDP                             *
' *************************************************************************************************

smpl %date_begin_a %date_end_a
series qgslwssfe = jgslfe * mhgslfe
     qgslwssfe.label(d) Real Potential Compensation: State & Local Government ($2009 Billions)
series gslwssfe = qgslwssfe * pgslwss
     gslwssfe.label(d) Potential Compensation: State & Local Government ($Billions)
series pgslwssfe = pgslwss

group component_list gslwssfe gslcca
series gdpgslfe = gslwssfe + gslcca
     gdpgslfe.label(d) Potential Gross Value Added: State & Local Government ($Billions)

call fisher_agg(component_list, gdpgslfe, @pagefreq, %base_year, %date_estimate_begin, %date_end_a)
series qgdpgslfe = qgdpgslfe + qgdpgsl_resfe
     qgdpgslfe.label(d) Real Potential Gross Value Added: State & Local Government ($2009 Billions)

delete pgslwssfe

' *************************************************************************************************
'                                Potential aggregate government GDP                               *
' *************************************************************************************************

smpl %date_begin_a %date_end_a
group component_list gdpgffe gdpgslfe
series gdpgfe = gdpgffe + gdpgslfe
     gdpgfe.label(d)     Potential Gross Value Added: Government ($Billions)
series pgdpgffe = pgdpgf
series pgdpgslfe = pgdpgsl

call fisher_agg(component_list, gdpgfe, @pagefreq, %base_year, %date_estimate_begin, %date_end_a)
series qgdpgfe = qgdpgfe + qgdpg_resfe
     qgdpgfe.label(d) Real Potential Gross Value Added: Government ($2009 Billions)
     pgdpgfe.label(d) Price Index, Potential GDP, Government ({%base_year} = 1.0)

delete pgdpgffe pgdpgslfe

' *************************************************************************************************
'                           Potential Nonfarm Business GDP (Equation (41))                        *
' *************************************************************************************************

smpl %date_begin_a %date_end_a
series qgdpnfbfe = exp( (kshare * log(icap(-1))) _
                      + ((1 - kshare) * log(ilabfe)) _
                      + log(iprodfe) _
                      + gdpconst )
     qgdpnfbfe.label(d) Real Potential Gross Value Added: Nonfarm Business ($2009 Billions)
series gdpnfbfe = qgdpnfbfe * pgdpnfb
     gdpnfbfe.label(d) Potential Gross Value Added: Nonfarm Business ($Billions)

' *************************************************************************************************
'                                          Potential GDP                                          *
' *************************************************************************************************

smpl %date_begin_a %date_end_a
group component_list gdpnfbfe gdpgfe gdpaffe gdpsvhfe
series gdpfe = gdpnfbfe + gdpgfe + gdpaffe + gdpsvhfe
     gdpfe.label(d) Potential Gross Domestic Product ($Billions)
series pgdpnfbfe = pgdpnfb
series pgdpaffe = pgdpaf
series pgdpsvhfe = pgdpsvh

call fisher_agg(component_list, gdpfe, @pagefreq, %base_year, %date_estimate_begin, %date_end_a)
series qgdpfe = qgdpfe + qgdp_resfe
     qgdpfe.label(d) Real Potential Gross Domestic Product ($2009 Billions)
     pgdpfe.label(d) Price Index, Potential GDP ({%base_year} = 1.0)

' *************************************************************************************************
'        Fisherize full-employment "other" GDP (government, farming, households, nonprofits)      *
' *************************************************************************************************

smpl %date_begin_a %date_end_a
group component_list gdpgfe gdpaffe gdpsvhfe
series gdpothfe = gdpgfe + gdpaffe + gdpsvhfe
     gdpothfe.label(d) Potential Gross Value Added: Other ($Billions)

call fisher_agg(component_list, gdpothfe, @pagefreq, %base_year, %date_estimate_begin, %date_end_a)
     qgdpothfe.label(d) Real Potential Gross Value Added: Other ($2009 Billions)
     pgdpothfe.label(d) Price Index, Potential GDP, Other ({%base_year} = 1.0)

delete pgdpnfbfe pgdpaffe pgdpsvhfe

' *************************************************************************************************
'   Produce a matrix of average annual growth rates of potential output and important components. *
' *************************************************************************************************

include subroutine_average_growth.prg

smpl %date_begin_a %date_end_a
matrix(14, 7) tablemat

series prod = qgdpfe / lcfe
series lagicap = icap(-1)
series dlqgdpnfbfe = log(qgdpnfbfe)-log(qgdpnfbfe(-1))
series prodnfbfe = qgdpnfbfe / mhnfbfe
series capital_labor = lagicap / mhnfbfe
series contrib_lab = (1-kshare)*(log(mhnfbfe)-log(mhnfbfe(-1)))
series contrib_cap = kshare*(log(lagicap)-log(lagicap(-1)))
series contrib_iprod = log(iprodfe)-log(iprodfe(-1))

for %row %var 1 qgdpfe 2 lcfe 3 prod 4 qgdpnfbfe 5 mhnfbfe 6 lagicap 7 iprodfe _
              12 prodnfbfe 13 capital_labor 14 qgdpothfe
     for %column %year1 %year2 1 1949 1973 2 1973 1981 3 1981 1990 4 1990 2001 5 2001 2007 _
                               6 2007 2016 7 1949 2016
          call average_growth({%var}, @pagefreq, %year1, %year2)
          tablemat({%row}, {%column}) = average_growth
     next
next

for %row %var 8 contrib_lab 9 contrib_cap 10 contrib_iprod
     for %column %year1 %year2 1 1950 1973 2 1974 1981 3 1982 1990 4 1991 2001 5 2002 2007 _
                               6 2008 2016 7 1950 2016
          smpl %year1 %year2
          tablemat({%row}, {%column}) = (exp(@mean({%var}))-1)*100
     next
next

for !i = 1 to 7
     tablemat(11,!i) = tablemat(8, !i) + tablemat(9, !i) + tablemat(10, !i)
next

' *************************************************************************************************
'            Write elements of the matric of average annuaal growth rates to a table.             *
' *************************************************************************************************

     table(31,8) results
     results.setwidth(@all) 9
     results.setwidth(1) 30
     setcell(results,1, 1,"ESTIMATED GROWTH OF POTENTIAL OUTPUT AND COMPONENTS","c")
     results.setmerge(a1:h1)
     results.setfont(a1:h8) +b

     setcell(results,2, 1,"By calendar year, in percent","c")
     results.setmerge(a2:h2)

     setcell(results,4, 2,"Average Annual Growth","c")
     results.setmerge(b4:h4)
     results.setlines(b4:h4) +b

     results.setheight(5) 0.1

     setcell(results,6, 2,"1950-","c")
     setcell(results,6, 3,"1974-","c")
     setcell(results,6, 4,"1982-","c")
     setcell(results,6, 5,"1991-","c")
     setcell(results,6, 6,"2002-","c")
     setcell(results,6, 7,"2008-","c")
     setcell(results,6, 8,"1950-","c")

     setcell(results,7, 2,"1973","c")
     setcell(results,7, 3,"1981","c")
     setcell(results,7, 4,"1990","c")
     setcell(results,7, 5,"2001","c")
     setcell(results,7, 6,"2007","c")
     setcell(results,7, 7,%date_end_a,"c")
     setcell(results,7, 8,%date_end_a,"c")
     results.setlines(a7:h7) +b
     results.setheight(8) 0.1

     setcell(results,8, 1,"OVERALL ECONOMY","l")
     results.setfont(8) +b
     setcell(results,9, 1,"   Potential Output","l")
     setcell(results,10, 1,"   Potential Labor Force","l")
     setcell(results,11, 1,"   Potential LF Productivity","l")
     setcell(results,13, 1,"NONFARM BUSINESS SECTOR","l")
     results.setfont(13) +b
     setcell(results,14, 1,"   Potential Output","l")
     setcell(results,16, 1,"      Pot. Hours Worked","l")
     setcell(results,17, 1,"      Capital Services","l")
     setcell(results,18, 1,"      Pot. Total Factor Productivity","l")
     setcell(results,20, 1,"   Contributions to Growth in Potential GDP in NFB Sector (Percentage Points)","l")
     setcell(results,21, 1,"      Potential Hours Worked","l")
     setcell(results,22, 1,"      Capital Services","l")
     setcell(results,23, 1,"      Pot. Total Factor Productivity","l")
     setcell(results,24, 1,"         Total of Contributions","l")
     setcell(results,26, 1,"   Memorandum:","l")
     setcell(results,27, 1,"      Potential Labor Productivity","l")
     setcell(results,28, 1,"      Capital-Labor Ratio","l")
     setcell(results,30, 1,"OTHER SECTORS","l")
     results.setfont(30) +b
     setcell(results,31, 1,"   Potential Output","l")
     results.setlines(a31,h31) +b

     for !i = 1 to 7
          !k = !i + 1
          for !j = 1 to 14
               if !j > 0 and !j < 4 then
                    !l = !j + 8
               else
                    if !j = 4 then
                         !l = !j + 10
                    else
                         if !j > 4 and !j < 8 then
                              !l = !j + 11
                         else
                              if !j > 7 and !j < 12 then
                                   !l = !j + 13
                              else
                                   if !j > 11 and !j < 14 then
                                        !l = !j + 15
                                   else
                                        !l = !j + 17
                                   endif
                              endif
                         endif
                    endif
               endif
               setcell(results, !l, !k, tablemat(!j, !i), "c", 2)
          next
     next

' *************************************************************************************************
'               Create figures illustrating the growth of actual and potential output             *
'         and illustrating the output gap (the gapo between actual and potential output).         *
' *************************************************************************************************

graph gr_qgdpfe.line qgdpfe qgdp
gr_qgdpfe.addtext(t) Historical Actual and Potential Output ($2009 B.)
gr_qgdpfe.axis(l) log
gr_qgdpfe.setelem(1) linepattern(1)
gr_qgdpfe.setelem(2) linepattern(2)
gr_qgdpfe.datelabel format("YYYY")
gr_qgdpfe.setelem(1) legend("Potential Output")
gr_qgdpfe.setelem(2) legend("Actual Output")

graph gr_gdpgap.line (qgdp/qgdpfe-1)*100 0
gr_gdpgap.addtext(t) Historical Output Gap (Percent)
gr_gdpgap.setelem(1) linepattern(1)
gr_gdpgap.setelem(2) linepattern(2)
gr_gdpgap.datelabel format("YYYY")

show results
show gr_gdpgap
show gr_qgdpfe

wfsave ".\CBO_Potential_Output_Estimate"
